# Generated by Django 3.2.6 on 2021-08-23 18:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0115_alter_images_size'),
    ]

    operations = [
        migrations.AddField(
            model_name='image_types',
            name='key',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
