# Generated by Django 2.2.5 on 2019-09-07 04:38

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0059_auto_20190905_0519'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='messages_files',
            name='message',
        ),
        migrations.CreateModel(
            name='Messages_files_refs',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('message', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='tracker.Messages')),
                ('messages_file', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='tracker.Messages_files')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
    ]
