# Generated by Django 3.2.4 on 2021-07-26 07:36

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.related


class Migration(migrations.Migration):
    dependencies = [
        ('react', '0003_fragment_params'),
    ]

    operations = [
        migrations.CreateModel(
            name='Fragment_param_types',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
            ],
            options={
                'verbose_name': 'Типы рараметров фрагмента',
            },
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='type',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='react.fragment_param_types'),
            preserve_default=False,
        ),
    ]
