# Generated by Django 3.0.7 on 2020-06-12 22:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('reports', '0008_auto_20200612_1625'),
    ]

    operations = [
        migrations.RenameField(
            model_name='jasper_reports',
            old_name='url',
            new_name='path',
        ),
    ]
