# Generated by Django 3.2 on 2021-04-09 04:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('history', '0014_auto_20200808_0428'),
    ]

    operations = [
        migrations.AlterField(
            model_name='history',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор'),
        ),
    ]
