# Generated by Django 3.2 on 2021-04-11 16:21

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0095_users_images_old_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='users_images',
            name='old_id',
        ),
        migrations.AddField(
            model_name='users_images',
            name='old_ids',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.BigIntegerField(), blank=True, null=True, size=None, unique=True),
        ),
    ]
