# Generated by Django 3.1.6 on 2021-02-20 05:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0070_auto_20210220_0519'),
    ]

    operations = [
        migrations.DeleteModel(
            name='AuditModelWithOldId',
        ),
    ]
