# Generated by Django 2.2.5 on 2019-09-13 10:55

import bitfield.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0015_auto_20190909_1357'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chat_user_user',
            name='common_id',
            field=models.PositiveIntegerField(default=None),
        ),
        migrations.AlterField(
            model_name='chat_users',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'), ('relevant', 'Актуальность')), db_index=True, default=0),
        ),
    ]
