# Generated by Django 3.2.7 on 2021-09-07 19:04

from django.db import migrations
from isc_common.common.functions import check_image_files


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0129_alter_images_unique_together'),
    ]

    operations = [
        migrations.RunPython(check_image_files)
    ]
