# Generated by Django 2.2.4 on 2019-08-21 01:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0008_auto_20190821_0109'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='day',
            options={'verbose_name': 'День'},
        ),
    ]
