# Generated by Django 2.1.7 on 2019-02-14 16:47

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0006_messages_parent'),
    ]

    operations = [
        migrations.AddField(
            model_name='messages',
            name='date_create',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Дата записи'),
        ),
    ]
