# Generated by Django 3.2.6 on 2021-08-23 11:26

from django.db import migrations


class Migration( migrations.Migration ) :
    dependencies = [
        ('isc_common' , '0108_alter_users_old_images_unique_together') ,
    ]

    operations = [
        migrations.RunSQL( '''DROP view all_tables;
                            CREATE OR REPLACE VIEW all_tables AS
                            SELECT table_name FROM information_schema.tables
                            WHERE table_schema NOT IN ('information_schema','pg_catalog')''' ) ,
    ]
