# Generated by Django 3.2.6 on 2021-08-29 13:47

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0123_alter_users_images_main_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='users_images',
            name='main_model',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
