# Generated by Django 3.1.6 on 2021-02-20 05:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0069_auditmodelwitholdid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='auditmodelwitholdid',
            name='old_id',
            field=models.BigIntegerField(default=None),
        ),
    ]
