# Generated by Django 2.2.4 on 2019-08-23 03:57

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0035_delete_calendar_shifts_days'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shift_day',
            name='calendar',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars'),
        ),
        migrations.AlterField(
            model_name='shift_day',
            name='numdayinweek',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterUniqueTogether(
            name='shift_day',
            unique_together={('calendar', 'numdayinweek')},
        ),
    ]
