# Generated by Django 3.2.6 on 2021-08-09 14:36

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.code_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0008_page_fragments_pages'),
    ]

    operations = [
        migrations.AddField(
            model_name='pages',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='react.pages'),
        ),
        migrations.AlterField(
            model_name='pages',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
