# Generated by Django 3.1.8 on 2021-04-22 00:01

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0096_auto_20210411_1621'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='images',
            name='sizes',
        ),
        migrations.AddField(
            model_name='image_types',
            name='sizes',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.SmallIntegerField(), blank=True, null=True, size=None),
        ),
    ]
