# Generated by Django 3.2.6 on 2021-08-09 15:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0010_fragments_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='page_fragments',
            name='fragment',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='react.fragments'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='page_fragments',
            name='page',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='react.pages'),
            preserve_default=False,
        ),
        migrations.AlterUniqueTogether(
            name='page_fragments',
            unique_together={('page', 'fragment')},
        ),
    ]
