# Generated by Django 3.2.7 on 2021-09-12 17:23

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0130_auto_20210907_1904'),
    ]

    operations = [
        migrations.AddField(
            model_name='text_informations',
            name='props',
            field=bitfield.models.BitField((('checked_src_icluded', 'Выполнена проверка на содержащие картинки'),), db_index=True, default=0),
        ),
    ]
