# Generated by Django 3.2.6 on 2021-08-23 12:21

from django.db import migrations


class Migration( migrations.Migration ) :
    dependencies = [
        ('isc_common' , '0109_auto_20210823_1126') ,
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='images' ,
            unique_together={ ('real_name' , 'size') } ,
        ) ,
    ]
