# Generated by Django 2.2.4 on 2019-08-23 03:50

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0033_auto_20190822_2250'),
    ]

    operations = [
        migrations.AddField(
            model_name='shift_day',
            name='calendar',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='clndr.Calendars'),
        ),
        migrations.AddField(
            model_name='shift_day',
            name='numdayinweek',
            field=models.PositiveIntegerField(default=None),
        ),
    ]
