# Generated by Django 3.2.6 on 2021-08-30 14:31

from django.db import migrations, models
import django.db.models.expressions


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0022_auto_20210812_0706'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='fragments',
            constraint=models.CheckConstraint(check=models.Q(('id', django.db.models.expressions.F('parent_id')), _negated=True), name='c_Fragments'),
        ),
    ]
