# Generated by Django 3.0.7 on 2020-06-12 16:23

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('reports', '0006_remove_jasper_reports_users_editor_identifier'),
    ]

    operations = [
        migrations.AddField(
            model_name='jasper_reports_users',
            name='editor_identifier',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
