# Generated by Django 3.1.7 on 2021-03-16 08:27

import django.contrib.auth.validators
from django.db import migrations

import isc_common.fields.code_field


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0086_auto_20210315_1154'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='username',
            field=isc_common.fields.code_field.CodeStrictField(error_messages={'unique': 'Такой пользователь уже существует.'}, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='логин'),
        ),
    ]
