# Generated by Django 3.2.4 on 2021-06-25 22:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('tracker', '0090_alter_messages_files_attfile'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages_files',
            name='size',
            field=models.BigIntegerField(default=0, verbose_name='Размер файла'),
        ),
    ]
