# Generated by Django 3.2.6 on 2021-08-23 18:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0116_image_types_key'),
    ]

    operations = [
        migrations.RenameField(
            model_name='image_types',
            old_name='key',
            new_name='keyImage',
        ),
    ]
