# Generated by Django 2.2.3 on 2019-07-28 19:36

from django.db import migrations, models
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0027_delete_history'),
    ]

    operations = [
        migrations.CreateModel(
            name='Mat_view',
            fields=[
                ('schemaname', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('relname', isc_common.fields.code_field.CodeField(blank=True, null=True, primary_key=True, serialize=False)),
                ('ownername', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('refresh_order', models.PositiveIntegerField()),
            ],
            options={
                'verbose_name': 'Mat Views',
                'db_table': 'mat_view_refresh_order',
                'managed': False,
            },
        ),
    ]
