# Generated by Django 2.2.4 on 2019-08-05 22:38

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0031_chat_users_chats_message_user_2_user'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='state',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='tracker.Messages_state'),
        ),
        migrations.AlterField(
            model_name='messages',
            name='theme',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='tracker.Messages_theme'),
        ),
        migrations.AlterField(
            model_name='messages',
            name='user',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='user', to=settings.AUTH_USER_MODEL),
        ),
    ]
