# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0015_delete_uuid_2_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='files_1c',
            name='id_old',
        ),
    ]
