# Generated by Django 3.2.7 on 2021-09-05 12:46

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0127_auto_20210901_0655'),
    ]

    operations = [
        migrations.AddField(
            model_name='images',
            name='file_name',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]
