# Generated by Django 3.2.6 on 2021-08-23 12:53

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0113_remove_images_image_type'),
    ]

    operations = [

    ]
