# Generated by Django 3.2.4 on 2021-07-26 20:06

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('react', '0004_auto_20210726_0736'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='fragments_item_types',
            options={'verbose_name': 'Типы элементов фрагментов'},
        ),
    ]
