# Generated by Django 2.2.4 on 2019-08-06 06:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0035_auto_20190806_0644'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Chat_users',
        ),
        migrations.DeleteModel(
            name='Chats',
        ),
    ]
