# Generated by Django 2.2.6 on 2019-10-17 10:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0071_messages_theme_admin_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='messages_theme_admin_view',
            table='tracker_messages_theme_admin_view',
        ),
    ]
