# Generated by Django 2.2.1 on 2019-05-17 18:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0023_fill_Messages_whom'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='messages',
            name='to_whom',
        ),
    ]
