# Generated by Django 2.2.2 on 2019-06-15 09:10

from django.db import migrations
import isc_common.fields.name_field


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='history',
            name='username',
            field=isc_common.fields.name_field.NameField(),
        ),
    ]
