# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0028_mat_view'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='params',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='user',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='user_permission',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='usergroup',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='usergroup_permission',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='widgets_trees',
            name='id_old',
        ),
    ]
