{% load static %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE|default:" en" }}">
<head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8"/>

    <meta http-equiv="Cache-Control" content="no-cache">
    <meta http-equiv="Expires" content="0">
    <meta http-equiv="Pragma" content="no-cache">

    <title>{% block title_text %}{% endblock %}</title>
    <link rel="shortcut icon" href="{% block icon %}{% endblock %}"/>

    <link rel="stylesheet" type="text/css" href="static/common-webapp/css/logging_styles.css"/>
    <link rel="stylesheet" href="static/dropzone/basic.css"/>
    <link rel="stylesheet" href="static/dropzone/dropzone.css" %}/>
    <link rel="stylesheet" href="static/css/myBoxedGridCell.css" %}/>
    <link rel="stylesheet" href="static/css/blink.css" %}/>

    <script>var isomorphicDir = "{% static "isomorphic" %}/"</script>
    <script>isc_css3Mode = "on";</script>
    <script>isc_useSimpleNames = false;</script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Core.js" %}></script>
    <script>isc.Time.setDefaultDisplayTimezone("00:00", true);</script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Foundation.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Containers.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Grids.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Forms.js" %}></script>
    <script type="text/javascript">isc.licenseType = "Enterprise"</script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_DataBinding.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Calendar.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_RichTextEditor.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_History.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Analytics.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Workflow.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Drawing.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_Charts.js" %}></script>
    <script type="text/javascript" src={% static "isomorphic/client/modules/ISC_FileLoader.js" %}></script>
    <script type="text/javascript" src={% static "js-beautify/beautify.js" %}></script>
    <script type="text/javascript" src={% static "jquery/jquery.js" %}></script>
{#    <script type="text/javascript" src={% static "g6/g6.js" %}></script>#}
{#    <script type="text/javascript" src={% static "d3/d3.js" %}></script>#}

    <script type="text/javascript" src={% static "dropzone/dropzone.js" %}></script>
{#    <script type="text/javascript" src={% static "ws/createReconnectWebSoket.js" %}></script>#}
    <script type="text/javascript" src={% static "isc/npm-smartclient-12.1.2.js" %}></script>
{#    <script type="text/javascript" src={% static "isc/npm-smartclient-12.1.0.min.js" %}></script>#}

    {% block js_code %}{% endblock %}
</head>
<body>
<iframe id="hiddenframe" name="hiddenframe" style="width:0px; height:0px; border:0px"></iframe>
{% block html_page %}{% endblock %}
<script>
    {% block start_page %}{% endblock %}
</script>
</body>
</html>
